@@ -1,5 +1,5 @@
-/* Tracker Extract - extracts embedded metadata from files
- * Copyright (C) 2007, Jason Kivlighn (jkivlighn@gmail.com)
+/*
+ * Copyright (C) 2007, Jason Kivlighn <jkivlighn@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -19,17 +19,9 @@
 
 #include "config.h"
 
-#include <glib.h>
 #include <gio/gio.h>
 
-#include <libtracker-common/tracker-ontologies.h>
-#include <libtracker-common/tracker-type-utils.h>
-#include <libtracker-common/tracker-file-utils.h>
-#include <libtracker-common/tracker-utils.h>
-
 #include <libtracker-extract/tracker-extract.h>
-#include <libtracker-extract/tracker-xmp.h>
-#include <libtracker-extract/tracker-utils.h>
 
 static void extract_xmp (const gchar          *filename,
                          TrackerSparqlBuilder *preupdate,
@@ -141,26 +133,30 @@ extract_xmp (const gchar          *uri,
              TrackerSparqlBuilder *preupdate,
              TrackerSparqlBuilder *metadata)
 {
+	TrackerXmpData xd = { 0 };
+	GError *error;
+	gchar *filename;
 	gchar *contents;
 	gsize length;
-	GError *error;
-	gchar *filename = g_filename_from_uri (uri, NULL, NULL);
-	TrackerXmpData xmp_data = { 0 };
+
+	filename = g_filename_from_uri (uri, NULL, NULL);
 
 	if (g_file_get_contents (filename, &contents, &length, &error)) {
-		gchar *orig_uri = find_orig_uri (filename);
+		gchar *original_uri;
+
+		original_uri = find_orig_uri (filename);
 
 		/* If no orig file is found for the sidekick, we use the sidekick to
-		 * describe itself instead, falling back to uri */
+		 * describe itself instead, falling back to uri 
+		 */
+		tracker_xmp_read (contents,
+		                  length,
+		                  original_uri ? original_uri : uri,
+		                  &xd);
 
-		tracker_extract_xmp_read (contents,
-		                          length,
-		                          orig_uri ? orig_uri : uri,
-		                          &xmp_data);
+		tracker_xmp_apply (metadata, uri, &xd);
 
-		tracker_extract_xmp_apply (metadata, uri, &xmp_data);
-
-		g_free (orig_uri);
+		g_free (original_uri);
 	}
 
 	g_free (filename);
